/* 
 *  This program is an interactive FAQ to ease investigations.
 *  Copyright (C) 2012 Julien Bruguier.
 * 
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 * 
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 * 
 *     You should have received a copy of the GNU General Public License
 *     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */ 

#ifndef __INVESTIGATION_DONNEES_DEBUGCONDITIONS__
#define __INVESTIGATION_DONNEES_DEBUGCONDITIONS__

#include <vector>
#include <set>
#include <string>
#include <src/global/global.h>
namespace Investigation { namespace Donnees { DECL_SHARED_PTR(DebugConditions); } }
#include <src/investigation/donnees/condition.h>

namespace Investigation
{
	namespace Donnees
	{
		class DebugConditions
		{
			public:
				DebugConditions(const std::vector<std::string>& requete)
				:_requete(requete) {};
				void operator<<(const SHARED_PTR(Investigation::Donnees::ExpressionRationnelle<std::string>)& regex) const
				{
					Investigation::Donnees::Patron<Investigation::Donnees::Glouton,std::string> patronglouton = *regex;
					std::cout << std::endl << "   Regular expression testing: " << std::endl;
					std::cout << std::endl << "      Greedy mode:     " ;
					if(patronglouton(_requete))
					{
						std::cout << "Input MATCHES the regex.";
					}
					else
					{
						std::cout << "Input DOES NOT MATCH the regex.";
					}
					Investigation::Donnees::Patron<Investigation::Donnees::NonGlouton,std::string> patronnonglouton = *regex;
					std::cout << std::endl << std::endl << "      Non greedy mode: ";
					if(patronnonglouton(_requete))
					{
						std::cout << "Input MATCHES the regex.";
					}
					else
					{
						std::cout << "Input DOES NOT MATCH the regex.";
					}
					std::cout << std::endl << std::endl;
					//	std::cout << patronglouton;
					//	std::cout << patronnonglouton;
				}
				void operator<<(const Investigation::Donnees::ConditionSP& condition) const
				{
					auto requete = Investigation::Donnees::Requete::requete(_requete);
					std::cout << std::endl << "   Condition testing: ";
					if((*condition)(requete))
					{
						std::cout << "Condition is TRUE." << std::endl << std::endl;
					}
					else
					{
						std::cout << "Condition is FALSE." << std::endl << std::endl;
					}
				}
			private:
				std::vector<std::string> _requete;
		};
	}
}
#endif
