/* 
 *  This program is an interactive FAQ to ease investigations.
 *  Copyright (C) 2012 Julien Bruguier.
 * 
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 * 
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 * 
 *     You should have received a copy of the GNU General Public License
 *     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */ 

#include <src/investigation/donnees/selectionreponse.h>

using namespace Investigation::Donnees;

SelectionReponse::SelectionReponse(const typename Selection<Reponse>::SequenceClauses& clauses, const SequenceReponses& clause_par_defaut)
	:Selection(clauses,clause_par_defaut)
{
}
SelectionReponse::SelectionReponse(const Selection<Reponse>& selection)
	:Selection<Reponse>(selection) {}
SelectionReponse::~SelectionReponse()
{
}
Html::SequenceLi SelectionReponse::operator() (const std::string& methode, const Requete& requete, Liens& liens) const
{
	std::vector<ReponseSP> reponses = static_cast<Selection<Reponse> > (*this)(requete); 
	Html::SequenceLi seq;
	for(auto it=reponses.cbegin() ; it!=reponses.cend() ; ++it)
	{
		Html::SequenceLi sous_sequence = (**it)(methode,requete,liens);
		seq.insert(seq.end(),sous_sequence.cbegin(),sous_sequence.cend());
	}
	return seq;
}
ReponseSP SelectionReponse::clone() const
{
	SelectionReponseSP reponse(new SelectionReponse(Selection<Reponse>::clone_interne()));
	return reponse;
}
std::set<std::string> SelectionReponse::operator[] (const Requete& requete)
{
	return Selection<Reponse>::operator[](requete);
}
bool SelectionReponse::operator%(const Reponse& reponse) const
{
	const SelectionReponse& selectionreponse=dynamic_cast<const SelectionReponse&>(reponse); // throw bad_cast
	return (*this)%(selectionreponse);
}
bool SelectionReponse::operator%(const SelectionReponse& reponse) const
{
	return Selection<Reponse>::operator%(reponse);
}
void SelectionReponse::liens_valides(const std::set<std::string>& identifiants) const
{
	std::vector<ReponseSP> reponses = (*this);
	for(auto it=reponses.cbegin() ; it!=reponses.cend() ; ++it)
	{
		(*it)->liens_valides(identifiants);
	}
}
void SelectionReponse::propage_infos(const std::string& page, const std::string& question)
{
	std::vector<ReponseSP> reponses = (*this);
	for(auto it=reponses.cbegin() ; it!=reponses.cend() ; ++it)
	{
		(*it)->propage_infos(page,question);
	}
}
void SelectionReponse::compte(CompteursSite& compteurs) const
{
	Selection<Reponse>::compte(compteurs);
}

IdentifiantPagesActives SelectionReponse::pages_actives_source(const Identifiant& page) const
{
	IdentifiantPagesActives id;
	SequenceReponses clause = (static_cast<Selection<Reponse> >(*this))();
	for(auto it=clause.cbegin() ; it!=clause.cend() ; ++it)
	{
		id += (*it)->pages_actives_source(page);
	}
	return id;
}
